==> als-server_2.12-4.2.1-sources.jar: org/mulesoft/als/server/lsp4j/extension/AlsInitializeParams.java <==
package org.mulesoft.als.server.lsp4j.extension;

import org.eclipse.lsp4j.ClientCapabilities;
import org.eclipse.lsp4j.InitializeParams;

public class AlsInitializeParams extends InitializeParams {

    private AlsClientCapabilities capabilities;
    private AlsConfiguration configuration;
    private ProjectConfigurationStyle projectConfigurationStyle;
    private Boolean hotReload;

    @Override
    public AlsClientCapabilities getCapabilities() {
        return capabilities;
    }

    public void setCapabilities(AlsClientCapabilities capabilities) {
        this.capabilities = capabilities;
    }

    @Override
    public void setCapabilities(ClientCapabilities capabilities) {
        AlsClientCapabilities acp = new AlsClientCapabilities();
        acp.setTextDocument(capabilities.getTextDocument());
        acp.setWorkspace(capabilities.getWorkspace());
        acp.setExperimental(capabilities.getExperimental());
        this.capabilities = acp;
    }
    
    public AlsConfiguration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(AlsConfiguration configuration) {
        this.configuration = configuration;
    }

    public ProjectConfigurationStyle getProjectConfigurationStyle() {
        return projectConfigurationStyle;
    }

    public void setProjectConfigurationStyle(ProjectConfigurationStyle projectConfigurationStyle) {
        this.projectConfigurationStyle = projectConfigurationStyle;
    }

    public Boolean getHotReload() {
        return hotReload;
    }

    public void setHotReload(Boolean hotReload) {
        this.hotReload = hotReload;
    }
}

==> als-server_2.12-5.4.2-0-sources.jar: org/mulesoft/als/server/lsp4j/extension/AlsInitializeParams.java <==
package org.mulesoft.als.server.lsp4j.extension;

import org.eclipse.lsp4j.ClientCapabilities;
import org.eclipse.lsp4j.InitializeParams;

public class AlsInitializeParams extends InitializeParams {

    private AlsClientCapabilities alsClientCapabilities;
    private AlsConfiguration configuration;
    private Boolean hotReload;
    private Boolean disableValidationAllTraces;

    @Override
    public AlsClientCapabilities getCapabilities() {
        return alsClientCapabilities;
    }

    public void setCapabilities(AlsClientCapabilities capabilities) {
        this.alsClientCapabilities = capabilities;
    }

    @Override
    public void setCapabilities(ClientCapabilities capabilities) {
        AlsClientCapabilities acp = new AlsClientCapabilities();
        acp.setTextDocument(capabilities.getTextDocument());
        acp.setWorkspace(capabilities.getWorkspace());
        acp.setExperimental(capabilities.getExperimental());
        this.alsClientCapabilities = acp;
    }

    public AlsConfiguration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(AlsConfiguration configuration) {
        this.configuration = configuration;
    }

    public Boolean getHotReload() {
        return hotReload;
    }

    public void setHotReload(Boolean hotReload) {
        this.hotReload = hotReload;
    }

    public Boolean getDisableValidationAllTraces() {
        return disableValidationAllTraces;
    }

    public void setDisableValidationAllTraces(Boolean disableValidationAllTraces) {
        this.disableValidationAllTraces = disableValidationAllTraces;
    }
}
